/*
 * Copyright (C) 2011 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android.SampleCamera;

import jp.co.sharp.android.hardware.CameraEx;
import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.AdapterView.OnItemClickListener;

/**
 * カメラメイン画面のアクティビティである。
 * カメラのメイン／サブをリストで表示し、選択したメイン/サブいずれかのカメラポジションを
 * インテントに渡して次の画面（プレビューアクティビティ(SampleCameraPreviewActivity)）を起動する。
 */
public class MainActivity extends Activity {
    private String[] mCameraName;
    
    /**
     *  アクティビティ作成時に呼ばれるメソッドである。
     *  リストビューにアダプタとクリックリスナの設定を行う。
     */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        setTitle(R.string.sample_camra_name);

        /* リストビュー取得 */
        ListView listView = (ListView)findViewById(R.id.camera_list);
        
        /* デバイスが利用可能なカメラの個数を取得する */
        int cameras = 0;
        cameras = CameraEx.getNumberOfCameras(); /* ★Addon用API使用箇所★ */
        
        
        if (cameras > 0) {
            /* カメラの数が0以上の場合、各カメラインフォを確認してカメラの名前をリストにする */
            mCameraName = new String [cameras];
            CameraEx.CameraInfo info = new CameraEx.CameraInfo(); /* ★Addon用API使用箇所★ */
            for (int i = 0; i < cameras; i++) {
                CameraEx.getCameraInfo(i, info); /* ★Addon用API使用箇所★ */
                if (info.facing == CameraEx.CameraInfo.CAMERA_FACING_BACK) {
                // 背面についている（アウトカメラ）
                    if (info.mode == CameraEx.CameraInfo.CAMERA_MODE_SINGLE) {
                        // 単眼モード
                        mCameraName[i] = getString(R.string.camera_main);
                    } else if (info.mode == CameraEx.CameraInfo.CAMERA_MODE_DOUBLE) {
                        // 二眼モード
                        mCameraName[i] = getString(R.string.camera_twin);
                    }
                } else if (info.facing == CameraEx.CameraInfo.CAMERA_FACING_FRONT) {
                // 液晶側についている（インカメラ）
                    mCameraName[i] = getString(R.string.camera_sub);
                }
            }
            /* アダプタ作成 */
            ArrayAdapter<String> arrayAdapter = new ArrayAdapter<String>(this,
                android.R.layout.simple_list_item_1, mCameraName);
            /* リストビューにアダプタを設定 */
            listView.setAdapter(arrayAdapter);
            
            /* クリックリスナを作成 */
            MyClickAdapter myClickAdapter = new MyClickAdapter();
            /* リストビューにクリックリスナを設定 */
            listView.setOnItemClickListener(myClickAdapter);
        }
    }
    
    /**
     * クリックリスナを実装したクラスである。
     * リストが選択された時にonItemClickを呼ぶ。
     * 選択された位置はpositionによって通知される。
     */
    class MyClickAdapter implements OnItemClickListener {
        public void onItemClick(AdapterView<?> adapter,
            View view, int position, long id) {
            /* インテント作成 */
            Intent intent = new Intent(MainActivity.this, PreviewActivity.class);
            
            /* リスト上で選択されたカメラポジションをインテントに設定 
             * カメラ名のリストを搭載されているカメラ情報から作成するため、
             * リストポジション＝カメラIDになる
             */
            intent.putExtra("camera_id", position);
            
            /* プレビュー画面のToastで表示するカメラ名をExtraに入れる */
            intent.putExtra("camera_name", mCameraName[position]);
            
            /* アクティビティを起動 */
            startActivityForResult(intent, 0);
        }
    }

}